% Input:
% dataDir, R_proj, T_proj, fc_cam, fc_proj, cc_cam, cc_proj, kc_cam, kc_proj, alpha_c_cam, alpha_c_proj

RecoverRigidTransformProjCam;

% Projector to camera rigid transform
R_proj = meanR;
T_proj = meanT;

% Projector internal parameters (from Bouguet)
fc_proj = fc;
cc_proj = cc;
kc_proj = kc;
alpha_c_proj = alpha_c;


% Camera internal parameters (from Matlab)
cameraMatrix = cameraParams.IntrinsicMatrix';
fc_cam(1) = cameraMatrix(1,1);
fc_cam(2) = cameraMatrix(2,2);
cc_cam = cameraMatrix(1:2,3);
alpha_c_cam = 0;
kc_cam = [cameraParams.RadialDistortion(1:2), cameraParams.TangentialDistortion, cameraParams.RadialDistortion(3)];

% Save the parameters to disk
om_proj = rodrigues(R_proj);
c = clock;
filename = ['Calib_proj_', num2str(c(3), '%.2d'), '.', num2str(c(2), '%.2d'), '.', num2str(c(1)), '.mat'];
save(fullfile(params.dataDir, filename), 'om_proj', 'R_proj', 'T_proj',...
    'fc_cam',  'cc_cam',  'kc_cam',  'alpha_c_cam', 'fc_proj', 'cc_proj', 'kc_proj', 'alpha_c_proj');

% Show the results
fprintf('Rotation vector:\n\n');
disp(om_proj);
fprintf('Translation vector:\n\n');
disp(T_proj);
