function  calibProjector( params,cameraParams,projectorPoints ) %#ok<*INUSD>
% Performs geometric calibration of the camera:
% Computes the 3D coordinates of the projected corners by projecting rays
% through the 2D coordinates of the corners in the camera image, and then
% intersecting them with the plane of the calibration board.

% Reload calibration data
[imagePointsProjectorAll, projectorPointsAll]  = reloadCalibrationData(params, 1); %#ok<ASGLU>
s = size(imagePointsProjectorAll);
numInternalCorners = prod(params.printedPatternSize - 1);

numberOfShots = s(3);
worldPointsProjCornersCameraCoord = zeros(numInternalCorners, 3, numberOfShots);
worldPointsProjCornersBoardCoord = zeros(numInternalCorners, 3, numberOfShots);
for i = 1:numberOfShots
    worldPointsProjCornersCameraCoord(:, :, i) = obtain3Dpoints_from_knownPlane(cameraParams.IntrinsicMatrix', eye(4),...
        cameraParams.RotationMatrices(:, :, i)', cameraParams.TranslationVectors(i, :)', imagePointsProjectorAll(:, :, i)')';
    
    % Bring the world points from the camera coordinates to board coordinates : XXc = Rc * XXb + Tc   =>   XXb = inv(Rc) * (XXc - Tc)
    worldPointsProjCornersBoardCoord(:, :, i) = (cameraParams.RotationMatrices(:, :, i)' \...
        (worldPointsProjCornersCameraCoord(:, :, i)' - cameraParams.TranslationVectors(i, :)' * ones(1, numInternalCorners)))';
end
worldPointsProjCornersBoardCoord(:, 3, :) = 0;

%%  Projector calibration with Bouguet's toolbox for camera calibration

% Prepare the variables in the format required by the Bouguet toolbox for camera calibration
for i = 1:numberOfShots
    eval(['x_', num2str(i), '= projectorPointsAll(:,:,',num2str(i),')'';']);
    eval(['X_', num2str(i), '= worldPointsProjCornersBoardCoord(:, :, ', num2str(i), ')'';']);
end

clear ny ny fc cc alpha_c kc cc_error;
active_images = ones(1, numberOfShots); %#ok<*NASGU>
n_ima = numberOfShots;
[ny, nx, ~] = size(params.projectedPattern); %#ok<ASGLU>

% Estimate the projector intrinsic parameters
go_calib_optim;

% Display the estimated projector calibration
if params.showFigures
    visualize_distortions;
    pause(0.3);
end

% Save the calibration parameters
save(fullfile(params.dataDir, 'proj_calib'), 'nx', 'ny', 'fc', 'cc', 'alpha_c', 'kc', 'cc_error');

%% Compute the rotation and the translation of the projector relative to the camera
PrepareCalibParamsFor3D;

end