function capturedImg = capturePhoto(params)
% Captures a photo by using the gphoto2 library for camera control.

% Check the input parameters
if nargin < 1
    outputFolder = pwd;
    imgFormat = 'raw';
else
    outputFolder = params.imageDir;
    imgFormat = params.imgFormat;
end

%% Set camera parameters: 
% unix('gphoto2 -q --list-all-config');
% unix('gphoto2 -q --set-config iso=100');
% unix('gphoto2 -q --set-config aperture=22');
% unix('gphoto2 -q --set-config shutterspeed=1/20');

%% Print settings summary before capture
% unix('gphoto2 -q --get-config imageformat');

%% Capture an image
try
    unix(['gphoto2 -q --capture-image-and-download --frames ', num2str(1), ' --filename "', outputFolder, filesep, 'capturedImg.%C"']);
catch
    error('Please turn on the camera.');
end

% Read the captured image from disk
switch imgFormat
    case {'raw', 'RAW', 'cr2', 'CR2'}
        capturedImg = imread(fullfile(outputFolder, 'capturedImg.CR2'));
    case {'jpg', 'JPG', 'jpeg', 'JPEG'}
        capturedImg = imread(fullfile(outputFolder, 'capturedImg.jpg'));
    case {'evf', 'evfmode'}
        capturedImg = imread(fullfile(outputFolder, 'capturedImg.jpg'));
    otherwise
        error('The requested image format is not supported.');
end

% Move the captured image to the folder containing all captured images
movefile(fullfile(params.imageDir, ['capturedImg.', params.imgFormat]), fullfile(params.imageDir, [num2str(params.currentImageNum, '%.2d'), '_step_', num2str(params.step), '.', params.imgFormat]));

end