function radVals = computeAverageRadiometricvalues(params, unwarpedProjectionPattern)
% Extracts the radiometric values from the image. For each corner, 4
% patches are extracted and the mean of their intesity is saved.

numInternalCorners = size(params.projectorPointsRounded, 1);
radVals = zeros(numInternalCorners, 4);
for i = 1:numInternalCorners % for each corner
    
    % Extract the 4 subsquares around each internal corner from the captured unwarped image
    patchTopLeft     = unwarpedProjectionPattern(params.projectorPointsRounded(i, 2) - params.squareCropSize - params.offsetFromCornerCenterRadiometric:params.projectorPointsRounded(i, 2) - params.offsetFromCornerCenterRadiometric,...
        params.projectorPointsRounded(i, 1) - params.squareCropSize - params.offsetFromCornerCenterRadiometric:params.projectorPointsRounded(i, 1) - params.offsetFromCornerCenterRadiometric, :);
    
    patchTopRight    = unwarpedProjectionPattern(params.projectorPointsRounded(i, 2) - params.squareCropSize - params.offsetFromCornerCenterRadiometric:params.projectorPointsRounded(i, 2) - params.offsetFromCornerCenterRadiometric,...
        params.projectorPointsRounded(i, 1) + params.offsetFromCornerCenterRadiometric:params.projectorPointsRounded(i, 1) + params.squareCropSize + params.offsetFromCornerCenterRadiometric, :);
    
    patchBottomRight = unwarpedProjectionPattern(params.projectorPointsRounded(i, 2) + params.offsetFromCornerCenterRadiometric:params.projectorPointsRounded(i, 2) + params.squareCropSize + params.offsetFromCornerCenterRadiometric,...
        params.projectorPointsRounded(i, 1) + params.offsetFromCornerCenterRadiometric:params.projectorPointsRounded(i, 1) + params.squareCropSize + params.offsetFromCornerCenterRadiometric, :);
    
    patchBottomLeft  = unwarpedProjectionPattern(params.projectorPointsRounded(i, 2) + params.offsetFromCornerCenterRadiometric:params.projectorPointsRounded(i, 2) + params.squareCropSize + params.offsetFromCornerCenterRadiometric,...
        params.projectorPointsRounded(i, 1) - params.squareCropSize - params.offsetFromCornerCenterRadiometric:params.projectorPointsRounded(i, 1) - params.offsetFromCornerCenterRadiometric, :);
    
    % Store the patches
    mTL = mean(mean(patchTopLeft, 2), 1);
    mTR = mean(mean(patchTopRight, 2), 1);
    mBR = mean(mean(patchBottomRight, 2), 1);
    mBL = mean(mean(patchBottomLeft, 2), 1);
    
    radVals(i, 1) = mTL(params.projectedPatternColorChannel);    
    radVals(i, 2) = mTR(params.projectedPatternColorChannel);    
    radVals(i, 3) = mBR(params.projectedPatternColorChannel); 
    radVals(i, 4) = mBL(params.projectedPatternColorChannel);  
    
end

end