function imagePoints = computeCornersProjectedPatternByOffset(imagePointsBoard, currentImg, params)
% Computes the corners of the projected pattern in step 2 by shiffting the
% previously detect corners in the printed pattern by half a square, and
% then refining their positions.

fprintf('extracting corners from the projected pattern (step 2)\n');

% Get the size of the printed pattern in the captured image
numInternalCorners2D = params.printedPatternSize - 1;
xyBoundingBox(1, :) = imagePointsBoard(1, :);
xyBoundingBox(2, :) = imagePointsBoard(sub2ind(numInternalCorners2D, 1, params.printedPatternSize(2) - 1), :);
xyBoundingBox(3, :) = imagePointsBoard(end, :);
xyBoundingBox(4, :) = imagePointsBoard(sub2ind(numInternalCorners2D, params.printedPatternSize(1) - 1, 1), :);

% Offset the positions by half a printed square
xyGuess = imagePointsBoard + repmat(((xyBoundingBox(3, :) - xyBoundingBox(1, :)) ./ 2) ./ fliplr(numInternalCorners2D - 1), [prod(numInternalCorners2D), 1]);

% Refine the corner estimates
sigma = ceil(sqrt((size(currentImg, 1) * size(currentImg, 2)) / (10^6)));
image = imfilter(currentImg, fspecial('gaussian', sigma * 6 + 1, sigma), 'symmetric', 'same');
imagePointsProjector = refineCorners(image, xyGuess, params);

% Save the computed corners
imagePoints = imagePointsProjector;
save(fullfile(params.dataDir, [num2str(params.currentImageNum, '%.2d'), '_x_cam_projected_step_2']), 'imagePoints');

% Display the detected corner locations
showCornerLocations(currentImg, imagePoints, params.projectedPatternColorChannel, params.showFigures);

end