function [imagePointsBoard, boardSizePrintedCaptured] = extractCorners(image, colorChannel, params)
% Extracts corners from the image in the correct color channel.
% It uses the built-in Matlab function detectCheckerboardPoints to extract
% the corners in a predefined image color channel. The image is downsampled
% to speed up the extraction, which is followed by corner refinement step
% to improve their accuracy.

% Extract corners
imSize = size(image);
imSizePx = imSize(1) * imSize(2);
downsampleFactor = ceil(sqrt(imSizePx / (10^6)));
imageSmall = imresize(image(:, :, colorChannel), 1 / downsampleFactor);
[imagePointsBoard, boardSizePrintedCaptured] = detectCheckerboardPoints(imageSmall(:, :));

% Refine corners
imagePointsBoard = imagePointsBoard * downsampleFactor;
image = imfilter(image, fspecial('gaussian', downsampleFactor * 6 + 1, downsampleFactor), 'symmetric', 'same');
if ~isempty(imagePointsBoard)
    imagePointsBoard = refineCorners(image(:, :, colorChannel), imagePointsBoard,params);
end

end