function [imagePoints, isCapturedImgGood] = extractCornersProcedure(params, currentImg, type)
% Extracts corners in the correct image channel, checks whether all corners
% were extracted and saves the result.
% 
% type = 0 : printed pattern, captured image (step 1);
% type = 1 : projected pattern, captured image (step 1);
% type = 2 : printed pattern, captured image (step 2);


if type == 0
    colorChannel = params.printedPatternColorChannel;
    fprintf('extracting corners from the printed pattern (step 1)\n');
elseif type == 1
    colorChannel = params.projectedPatternColorChannel;
    fprintf('extracting corners from the projected pattern (step 1)\n');
elseif type == 2
    colorChannel = params.printedPatternColorChannel;
    fprintf('extracting corners from the printed pattern (step 2)\n');
else
    error('incorrect type');
end

isCapturedImgGood = 1;
boardSize = params.printedPatternSize;

% Detect the checkerboard corners
[imagePoints, boardSizeCaptured] = extractCorners(currentImg, colorChannel, params);

% Orient the checkerboard correctly (first corner is top-left, column-major counting)
imagePoints = orientCheckerboard(imagePoints, boardSizeCaptured);

% Display the detected corner locations
showCornerLocations(currentImg, imagePoints, colorChannel, params.showFigures);

% Check if it found all the corners from the printed pattern in the captured image
if ~isequal(boardSizeCaptured, boardSize)
    isCapturedImgGood = 0;
    
    if colorChannel == params.printedPatternColorChannel
        typeString = 'PRINTED';
    else
        typeString = 'PROJECTED';
    end
    
    fprintf(['Image number ', num2str(params.currentImageNum), ': Could not detect all corners in the ', typeString, ' pattern.\nIteration aborted...\n']);
    beep;
    
    % Project a red image
    projectImage(params.redImage);
    pause(1);
    
    % Project the original checkerboard pattern
    projectImage(params.projectedPattern)
    pause(3);
    
    % Delete the stored data for this iteration
    delete(fullfile(params.dataDir, [num2str(params.currentImageNum, '%.2d'), '*']));
    
    return;
end

% Save the detected corner positions to disk
if type == 2
    save(fullfile(params.dataDir, [num2str(params.currentImageNum, '%.2d'), '_x_cam_printed_step_2']), 'imagePoints');
elseif type == 1
    save(fullfile(params.dataDir, [num2str(params.currentImageNum, '%.2d'), '_x_cam_projected_step_1']), 'imagePoints');
elseif type == 0
    save(fullfile(params.dataDir, [num2str(params.currentImageNum, '%.2d'), '_x_cam_printed_step_1']), 'imagePoints');
end

end