function [inVals, validIdx] = getIndexOfProjectedSquares(params)
% Returns the indices of the white squares which are to be used for
% radiometric calibration. It also returns their input intensity values
% (their values in the calibration chart).

% Find the index of each projected square
[IX, IY] = meshgrid(1:params.printedPatternSize(2) - 1, 1:params.printedPatternSize(1) - 1);
indicesTopLeft = sub2ind(params.printedPatternSize, IY(:), IX(:));
indicesTopRight = indicesTopLeft + params.printedPatternSize(1);
indicesBottomRight = indicesTopRight + 1;
indicesBottomLeft = indicesTopLeft + 1;
indicesRadiometric = [indicesTopLeft, indicesTopRight, indicesBottomRight, indicesBottomLeft];

% Get the input value for each projected (output) value
inputValuesRadiometric = params.checkerboardPattern(indicesRadiometric);

% Extract only the valid values, i.e. the image intensity only for the
% squares that land on white paper (every other square)
numInternalCorners = prod(params.printedPatternSize - 1);
if params.isfirstSquareBlack
    validIdx = 2:2:numInternalCorners;
else
    validIdx = 1:2:numInternalCorners;
end
inVals = inputValuesRadiometric(2:2:end, :);
inVals = inVals + 0.00001;

end