function pointsOut = orientCheckerboard(points, boardSize)
% orientCheckerboard gives a consistent order to the corners points. The
% inital order is determined by Matlab's built-in function
% detectCherckerBoardPoints. This order can vary and depends on the
% position of the first exterior black square. If this square is in
% top-left corner of the checkerboard points are sorted by column from top
% to bottom starting from the left column. If the first black square is not
% at the top-left corner corners are re-sorted to math the previous order.
% 
% Input:
% points : x,y coordinates of the detect corners, 2x(m-1)*(n-1)
% boardSize : size of the board mxn


pointsOut = points;

firstPoint = points(1, :);
finalPoint = points(end, :);

diff = finalPoint - firstPoint;
if sum(diff < 0) > 0
    boardSize = boardSize - 1;
    pointsTemp = reshape(points, [boardSize(1), boardSize(2), 2]);
    pointsTemp = rot90(pointsTemp, 2);
    pointsOut = reshape(pointsTemp, [boardSize(1) * boardSize(2), 2]);
end

end