function [warpedProjectionPattern, H_projectorToBoard_prewarp] = prewarpProjectedPattern(params, imagePointsPrinted, imagePointsProjected)
% Prewarps the projected pattern such that its corners are projected in the
% centers of the white squares of the printed pattern.

% Compute the homography that relates the camera image with the calibration board
% by using the printed corners XY positions and their images in the captured image.
% 'squareSize / 2' adds offset on the compositing surface of half a printed
% square, to displace the projected pattern in relation to the printed pattern.
H_cameraToBoard_offset = compute_homography(params.printedPoints' - params.squareSize / 2, imagePointsPrinted');

% Compute the homography that relates the projector image with the camera image (by using the projected corners)
H_projectorToCamera_projectedSize = compute_homography(imagePointsProjected',params.projectedPoints');

%  Compute a composite homography that relates the projector image to the calibration board
H_boardToProjector = inv(H_projectorToCamera_projectedSize) * inv(H_cameraToBoard_offset);
H_boardToProjector = H_boardToProjector ./ H_boardToProjector(3, 3);

% Compute corner positions of the printed pattern and the warped projector pattern
% Printed pattern corner points
boardPointsProjImg = H_boardToProjector * [params.printedPoints'; ones(1, size(params.projectedPoints, 1))]; % compute the board corner points in the projector space
boardPointsProjImg = boardPointsProjImg ./ (ones(3, 1) * boardPointsProjImg(3, :)); % divide by the third coordinate
boardPointsProjImg = boardPointsProjImg';

% Warp the projected pattern such that its corners are projected in the centers of the squares of the printed pattern
H_projectorToBoard_prewarp = compute_homography(boardPointsProjImg(:, 1:2)', params.projectedPoints');
H_boardToProjector_prewarp = inv(H_projectorToBoard_prewarp);

% Warp the canvas with the board-to-projector homography (computes the location on the board for every projector pixel)
warpedProjectionPattern = warpImage(params, params.projectedPattern, H_boardToProjector_prewarp, 1);

% Display the prewarped image
if params.showFigures
    figure, imshow(warpedProjectionPattern);
    pause(0.3);
end

end