function boardPointsProjImg = printedCornersProjImage(params, imagePointsPrinted, imagePointsProjected)
% This function computes the positions of the printed corners into the
% projector coordinate space.

% Compute the homography that relates the camera image with the calibration board
% by using the printed corners XY positions and their locations in the captured image
H_cameraToBoard = compute_homography(params.printedPoints', imagePointsPrinted');

% Compute the homography that relates the projector image with the camera image (by using the projected corners)
H_projectorToCamera_projectedSize = compute_homography(imagePointsProjected', params.projectedPoints');

% Compute a composite homography that relates the projected image to the calibration board
H_boardToProjector = inv(H_projectorToCamera_projectedSize) * inv(H_cameraToBoard);
H_boardToProjector = H_boardToProjector ./ H_boardToProjector(3, 3);

% Compute the corner positions of the printed pattern in the projector image
boardPointsProjImg = H_boardToProjector * [params.printedPoints'; ones(1, size(params.projectedPoints, 1))];
boardPointsProjImg = boardPointsProjImg ./ (ones(3, 1) * boardPointsProjImg(3, :));
boardPointsProjImg = boardPointsProjImg';

end