function imagePointsBoardRefined = refineCorners(img, imagePointsBoard, params)
% This function is used to improve the precision of the corners found by
% the function extraCorners. The corners are approximate because in order
% to speed up the corners extraction we downsample the image. These corners
% are used as initial guess and are given to the function cornerfinder from
% the Bouguet Toolbox which then uses Harris corners detection to refine
% the corner locations.
% 
%   img              : current image in the correct color channel 2D
%   imagePointsBoard : corners to be refined 2xN

boardSize = params.printedPatternSize;
w = (max(imagePointsBoard(:, 1)) - min(imagePointsBoard(:, 1))) / boardSize(2);
h = (max(imagePointsBoard(:, 2)) - min(imagePointsBoard(:, 2))) / boardSize(1);
w = floor(w/8); h = floor(h/8); % search region
imagePointsBoardRefined = cornerfinder(imagePointsBoard', img, w, h);
imagePointsBoardRefined = imagePointsBoardRefined';

end