function  outImage = warpImage(params, inImage, H, prewarp)
% Warps the input image 'inImage' with the supplied homography 'H'.

u = params.u; v = params.v;
[height, width] = size(u);
channels = size(inImage, 3);
outImage = zeros(height, width, channels);

% Warp the canvas with the provided homography (computes the corresponding pixel coordinates in the new image)
z_ =  H(3, 1) * u + H(3, 2) * v + H(3, 3);
u_ = (H(1, 1) * u + H(1, 2) * v + H(1, 3)) ./ z_;
v_ = (H(2, 1) * u + H(2, 2) * v + H(2, 3)) ./ z_;

% Interpolate the output image from the input image on to the canvas
for i = 1:channels
    outImage(:, :, i) = interp2(im2double(inImage(:, :, i)), u_, v_, 'linear');
end
outImage(isnan(outImage)) = 0;

% If processing the prewarped image, make the background magenta (complementary color to the printed pattern)
if prewarp
    mask = sum(outImage, 3) == 0;
    outImage(repmat(mask, [1, 1, 3])) = repmat(cat(3, 1, 0, 1), [sum(sum(mask)), 1]);
    
    % Save the image to disk
    imwrite(outImage, fullfile(params.imageDir, [num2str(params.currentImageNum, '%.2d_prewarped_projector_pattern'), '.png']));    
else
    imwrite(outImage, fullfile(params.imageDir, [num2str(params.currentImageNum, '%.2d_unwarped_projector_pattern'), '.tiff']));
end

end